@@ -1,5 +1,9 @@
 import boto3
 import simplejson as json
+import os
+
+
+ENVIRONMENT = os.getenv("ENVIRONMENT")
 
 
 class Queue(object):
@@ -17,7 +21,22 @@ class Queue(object):
         # some kind of context?
         self.queue_name = "legoon-" + self.__class__.__name__.lower() + "-prod"
         print(self.queue_name)
-        self.client = boto3.client("sqs")
+        print(f"Environment: {ENVIRONMENT}")
+        if ENVIRONMENT == "sam":
+            print("Using localstack for queues.")
+            endpoint_url = "http://localstack:4566"
+            self.client = boto3.client(
+                "sqs", region_name="us-east-1", endpoint_url=endpoint_url
+            )
+        elif ENVIRONMENT == "local":
+            print("Using localhost for queues.")
+            endpoint_url = "http://localhost:4566"
+            self.client = boto3.client(
+                "sqs", region_name="us-east-1", endpoint_url=endpoint_url
+            )
+        else:
+            self.client = boto3.client("sqs")
+
         self.queue_url = self.client.get_queue_url(QueueName=self.queue_name)[
             "QueueUrl"
         ]
